@@ -1,7 +1,7 @@
 package Acme::CPANLists::PERLANCAR::Avoided;
 
-our $DATE = '2016-02-20'; # DATE
-our $VERSION = '0.10'; # VERSION
+our $DATE = '2016-02-25'; # DATE
+our $VERSION = '0.11'; # VERSION
 
 our @Module_Lists = (
     {
@@ -47,6 +47,26 @@ _
                 summary => 'Use the newer File::Slurper instead',
                 alternate_modules => ['File::Slurper'],
             },
+            {
+                module => 'Exporter::Lite',
+                summary => 'Unnecessary, use Exporter instead',
+                description => <<'_',
+
+I used to use this module because I didn't know that `Exporter` can also be used
+without subclassing, i.e. instead of:
+
+    use Exporter;
+    our @ISA = qw(Exporter);
+    our @EXPORT = (...);
+
+you can also use it like this:
+
+    use Exporter qw(import);
+    our @EXPORT = (...);
+
+_
+                alternate_modules => ['Exporter'],
+            },
         ],
     },
 );
@@ -66,7 +86,7 @@ Acme::CPANLists::PERLANCAR::Avoided - Modules I'm currently avoiding
 
 =head1 VERSION
 
-This document describes version 0.10 of Acme::CPANLists::PERLANCAR::Avoided (from Perl distribution Acme-CPANLists-PERLANCAR), released on 2016-02-20.
+This document describes version 0.11 of Acme::CPANLists::PERLANCAR::Avoided (from Perl distribution Acme-CPANLists-PERLANCAR), released on 2016-02-25.
 
 =head1 MODULE LISTS
 
@@ -104,6 +124,23 @@ Alternate modules: L<File::Slurper>
 
 Alternate modules: L<File::Slurper>
 
+=item * L<Exporter::Lite> - Unnecessary, use Exporter instead
+
+I used to use this module because I didn't know that C<Exporter> can also be used
+without subclassing, i.e. instead of:
+
+ use Exporter;
+ our @ISA = qw(Exporter);
+ our @EXPORT = (...);
+
+you can also use it like this:
+
+ use Exporter qw(import);
+ our @EXPORT = (...);
+
+
+Alternate modules: L<Exporter>
+
 =back
 
 =head1 HOMEPAGE
